# -*- coding: utf-8 -*-
"""Setup module for flask taxonomy."""
import os

from setuptools import find_packages, setup

readme = open('README.md').read()
history = open('CHANGES.md').read()
OAREPO_VERSION = os.environ.get('OAREPO_VERSION', '3.3.0')


install_requires = [
    'pycountry',
    'oarepo-mapping-includes',
    'oarepo-invenio-model',
    'oarepo-validate',
    'idutils',
    'edtf',
    'oarepo-multilingual',
    'marshmallow-utils>=0.4.0',
    'oarepo-taxonomies'
]

tests_require = [
    'pydocstyle',
]

extras_require = {
    'tests': [
        *tests_require,
        'oarepo[tests]~={version}'.format(
            version=OAREPO_VERSION)]
}

setup_requires = [
    'pytest-runner>=2.7',
]

g = {}
with open(os.path.join('oarepo_rdm_records', 'version.py'), 'rt') as fp:
    exec(fp.read(), g)
    version = g['__version__']

packages = find_packages(exclude=['tests', 'tests.test_module'])

os.environ.get('INVENIO_INSTANCE_PATH', 'var/instance')

taxonomy_data = [os.path.join('taxonomies', f) for f in os.listdir('taxonomies')]
data_files = [('var/instance/taxonomies', taxonomy_data)]
print(data_files)

setup(
    name="oarepo_rdm_records",
    version=version,
    url="https://github.com/oarepo/oarepo-rdm-records",
    license="MIT",
    author="Alzbeta Pokorna",
    author_email="alzbeta.pokorna@cesnet.cz",
    description="OARepo rdm records data model",
    long_description=readme + '\n\n' + history,
    long_description_content_type='text/markdown',
    zip_safe=False,
    packages=packages,
    entry_points={
        'oarepo_mapping_includes': [
          'oarepo_rdm_records = oarepo_rdm_records.included_mappings'
        ],
        'invenio_jsonschemas.schemas': [
            'oarepo_rdm_records = oarepo_rdm_records.jsonschemas',
        ],
    },
    data_files=data_files,
    include_package_data=True,
    setup_requires=setup_requires,
    extras_require=extras_require,
    install_requires=install_requires,
    tests_require=tests_require,
    platforms='any',
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Development Status :: 4 - Beta',
    ],
)
